@@ -50,12 +50,13 @@ class SyncHttpClient(base_client.BaseHttpClient):
             401: HTTPUnauthorizedError,
             400: HTTPIncorrectParametersError,
         }
-
+        # Format error message with status code
+        error_message = f"HTTP {response.status_code}: {response.text}"
         exc = status_codes_exceptions.get(response.status_code)
         if exc:
-            raise exc()
+            raise exc(error_message, response)
         else:
-            raise HTTPResponseError(response.text)
+            raise HTTPResponseError(error_message, response)
 
     def _handle_connection_error(self, e):
         '''
@@ -109,7 +110,7 @@ class SyncHttpClient(base_client.BaseHttpClient):
             else:
                 break
             
-        if not (response.status_code == 200 or response.status_code == 204):
+        if not (response.status_code == 200 or response.status_code == 204 or response.status_code == 201):
             LOGGER.warning('RESPONSE CODE: %s' % response.status_code)
             self._handle_invalid_response(response)
 
