@@ -12,3 +12,8 @@ from splitapiclient.microclients.user_microclient import UserMicroClient
 from splitapiclient.microclients.group_microclient import GroupMicroClient
 from splitapiclient.microclients.apikey_microclient import APIKeyMicroClient
 from splitapiclient.microclients.restriction_microclient import RestrictionMicroClient
+from splitapiclient.microclients.flag_set_microclient import FlagSetMicroClient
+from splitapiclient.microclients.large_segment_microclient import LargeSegmentMicroClient
+from splitapiclient.microclients.large_segment_definition_microclient import LargeSegmentDefinitionMicroClient
+from splitapiclient.microclients.rule_based_segment_microclient import RuleBasedSegmentMicroClient
+from splitapiclient.microclients.rule_based_segment_definition_microclient import RuleBasedSegmentDefinitionMicroClient
\ No newline at end of file
