@@ -13,3 +13,8 @@ from splitapiclient.resources.user import User
 from splitapiclient.resources.group import Group
 from splitapiclient.resources.apikey import APIKey
 from splitapiclient.resources.restriction import Restriction
+from splitapiclient.resources.flag_set import FlagSet
+from splitapiclient.resources.large_segment import LargeSegment
+from splitapiclient.resources.large_segment_definition import LargeSegmentDefinition
+from splitapiclient.resources.rule_based_segment import RuleBasedSegment
+from splitapiclient.resources.rule_based_segment_definition import RuleBasedSegmentDefinition
\ No newline at end of file
