@@ -36,7 +36,34 @@ class SegmentDefinition(BaseResource):
     @property
     def name(self):
         return self._name
-            
+
+    @property
+    def traffic_type(self):
+        return None if self._trafficType == {} else self._trafficType
+        
+    @property
+    def environment(self):
+        return self._environment
+
+    @property
+    def tags(self):
+        return self._tags
+
+    @property
+    def creation_time(self):
+        return None if  self._creationTime==0 else self._creationTime
+
+    def get_key_count(self, apiclient=None):
+        '''
+        Get the key count for this segment definition in this environment
+
+        :returns: the key count for the segment definition
+        :rtype: integer
+        '''
+        imc = require_client('SegmentDefinition', self._client, apiclient)
+        return imc.get_key_count(self._name, self._environment['id'])
+
+
     def get_keys(self, apiclient=None):
         '''
         Get list of keys in segment in environment
@@ -86,7 +113,27 @@ class SegmentDefinition(BaseResource):
         :rtype: boolean
         '''
         imc = require_client('SegmentDefinition', self._client, apiclient)
-        return imc.import_keys_from_json(self._name, self._environment['id'], replace_keys, json_data)
+        keys = json_data['keys']
+        if(len(keys) > 10000):
+            # Split keys into batches of 10,000
+            key_batches = [keys[i:i + 10000] for i in range(0, len(keys), 10000)]
+            success = True
+            # Process each batch
+            first_batch = True
+            for key_batch in key_batches:
+                # Make a copy of the json_data to avoid modifying the original
+                batch_data = json_data.copy()
+                batch_data['keys'] = key_batch
+                # If any batch fails, mark the entire operation as failed
+                # First batch uses original replace_keys value, subsequent batches use False
+                batch_replace_keys = replace_keys if first_batch else False
+                batch_result = imc.import_keys_from_json(self._name, self._environment['id'], batch_replace_keys, batch_data)
+                if not batch_result:
+                    success = False
+                first_batch = False
+            return success
+        else:
+            return imc.import_keys_from_json(self._name, self._environment['id'], replace_keys, json_data)
 
     def remove_keys(self, json_data, apiclient=None):
         '''
